@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for docdb service client
 
@@ -10,11 +11,14 @@ Usage::
     client: DocDBClient = boto3.client("docdb")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from datetime import datetime
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+from botocore.waiter import Waiter as Boto3Waiter
+
 from mypy_boto3_docdb.paginator import (
     DescribeDBClustersPaginator,
     DescribeDBEngineVersionsPaginator,
@@ -127,26 +131,26 @@ class Exceptions:
 
 class DocDBClient:
     """
-    [DocDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client)
+    [DocDB.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client)
     """
 
     exceptions: Exceptions
 
     def add_tags_to_resource(self, ResourceName: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
+        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
         """
 
     def apply_pending_maintenance_action(
         self, ResourceIdentifier: str, ApplyAction: str, OptInType: str
     ) -> ApplyPendingMaintenanceActionResultTypeDef:
         """
-        [Client.apply_pending_maintenance_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
+        [Client.apply_pending_maintenance_action documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.can_paginate)
         """
 
     def copy_db_cluster_parameter_group(
@@ -157,7 +161,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CopyDBClusterParameterGroupResultTypeDef:
         """
-        [Client.copy_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
+        [Client.copy_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
         """
 
     def copy_db_cluster_snapshot(
@@ -170,7 +174,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CopyDBClusterSnapshotResultTypeDef:
         """
-        [Client.copy_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
+        [Client.copy_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
         """
 
     def create_db_cluster(
@@ -195,7 +199,7 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> CreateDBClusterResultTypeDef:
         """
-        [Client.create_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.create_db_cluster)
+        [Client.create_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.create_db_cluster)
         """
 
     def create_db_cluster_parameter_group(
@@ -206,7 +210,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterParameterGroupResultTypeDef:
         """
-        [Client.create_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
+        [Client.create_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
         """
 
     def create_db_cluster_snapshot(
@@ -216,7 +220,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterSnapshotResultTypeDef:
         """
-        [Client.create_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
+        [Client.create_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
         """
 
     def create_db_instance(
@@ -232,7 +236,7 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> CreateDBInstanceResultTypeDef:
         """
-        [Client.create_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.create_db_instance)
+        [Client.create_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.create_db_instance)
         """
 
     def create_db_subnet_group(
@@ -243,7 +247,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBSubnetGroupResultTypeDef:
         """
-        [Client.create_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
+        [Client.create_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
         """
 
     def delete_db_cluster(
@@ -253,29 +257,29 @@ class DocDBClient:
         FinalDBSnapshotIdentifier: str = None,
     ) -> DeleteDBClusterResultTypeDef:
         """
-        [Client.delete_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
+        [Client.delete_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
         """
 
     def delete_db_cluster_parameter_group(self, DBClusterParameterGroupName: str) -> None:
         """
-        [Client.delete_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
+        [Client.delete_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
         """
 
     def delete_db_cluster_snapshot(
         self, DBClusterSnapshotIdentifier: str
     ) -> DeleteDBClusterSnapshotResultTypeDef:
         """
-        [Client.delete_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
+        [Client.delete_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
         """
 
     def delete_db_instance(self, DBInstanceIdentifier: str) -> DeleteDBInstanceResultTypeDef:
         """
-        [Client.delete_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.delete_db_instance)
+        [Client.delete_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.delete_db_instance)
         """
 
     def delete_db_subnet_group(self, DBSubnetGroupName: str) -> None:
         """
-        [Client.delete_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
+        [Client.delete_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
         """
 
     def describe_certificates(
@@ -286,7 +290,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> CertificateMessageTypeDef:
         """
-        [Client.describe_certificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_certificates)
+        [Client.describe_certificates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_certificates)
         """
 
     def describe_db_cluster_parameter_groups(
@@ -297,7 +301,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupsMessageTypeDef:
         """
-        [Client.describe_db_cluster_parameter_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
+        [Client.describe_db_cluster_parameter_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
         """
 
     def describe_db_cluster_parameters(
@@ -309,14 +313,14 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupDetailsTypeDef:
         """
-        [Client.describe_db_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
+        [Client.describe_db_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
         """
 
     def describe_db_cluster_snapshot_attributes(
         self, DBClusterSnapshotIdentifier: str
     ) -> DescribeDBClusterSnapshotAttributesResultTypeDef:
         """
-        [Client.describe_db_cluster_snapshot_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
+        [Client.describe_db_cluster_snapshot_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
         """
 
     def describe_db_cluster_snapshots(
@@ -331,7 +335,7 @@ class DocDBClient:
         IncludePublic: bool = None,
     ) -> DBClusterSnapshotMessageTypeDef:
         """
-        [Client.describe_db_cluster_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
+        [Client.describe_db_cluster_snapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
         """
 
     def describe_db_clusters(
@@ -342,7 +346,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterMessageTypeDef:
         """
-        [Client.describe_db_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
+        [Client.describe_db_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
         """
 
     def describe_db_engine_versions(
@@ -358,7 +362,7 @@ class DocDBClient:
         ListSupportedTimezones: bool = None,
     ) -> DBEngineVersionMessageTypeDef:
         """
-        [Client.describe_db_engine_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
+        [Client.describe_db_engine_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
         """
 
     def describe_db_instances(
@@ -369,7 +373,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBInstanceMessageTypeDef:
         """
-        [Client.describe_db_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_instances)
+        [Client.describe_db_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_instances)
         """
 
     def describe_db_subnet_groups(
@@ -380,7 +384,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBSubnetGroupMessageTypeDef:
         """
-        [Client.describe_db_subnet_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
+        [Client.describe_db_subnet_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
         """
 
     def describe_engine_default_cluster_parameters(
@@ -391,14 +395,14 @@ class DocDBClient:
         Marker: str = None,
     ) -> DescribeEngineDefaultClusterParametersResultTypeDef:
         """
-        [Client.describe_engine_default_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
+        [Client.describe_engine_default_cluster_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
         """
 
     def describe_event_categories(
         self, SourceType: str = None, Filters: List[FilterTypeDef] = None
     ) -> EventCategoriesMessageTypeDef:
         """
-        [Client.describe_event_categories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_event_categories)
+        [Client.describe_event_categories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_event_categories)
         """
 
     def describe_events(
@@ -421,7 +425,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> EventsMessageTypeDef:
         """
-        [Client.describe_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_events)
+        [Client.describe_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_events)
         """
 
     def describe_orderable_db_instance_options(
@@ -436,7 +440,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> OrderableDBInstanceOptionsMessageTypeDef:
         """
-        [Client.describe_orderable_db_instance_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
+        [Client.describe_orderable_db_instance_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
         """
 
     def describe_pending_maintenance_actions(
@@ -447,14 +451,14 @@ class DocDBClient:
         MaxRecords: int = None,
     ) -> PendingMaintenanceActionsMessageTypeDef:
         """
-        [Client.describe_pending_maintenance_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
+        [Client.describe_pending_maintenance_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
         """
 
     def failover_db_cluster(
         self, DBClusterIdentifier: str = None, TargetDBInstanceIdentifier: str = None
     ) -> FailoverDBClusterResultTypeDef:
         """
-        [Client.failover_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
+        [Client.failover_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
         """
 
     def generate_presigned_url(
@@ -465,14 +469,14 @@ class DocDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
         """
 
     def list_tags_for_resource(
         self, ResourceName: str, Filters: List[FilterTypeDef] = None
     ) -> TagListMessageTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
         """
 
     def modify_db_cluster(
@@ -492,14 +496,14 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> ModifyDBClusterResultTypeDef:
         """
-        [Client.modify_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
+        [Client.modify_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
         """
 
     def modify_db_cluster_parameter_group(
         self, DBClusterParameterGroupName: str, Parameters: List["ParameterTypeDef"]
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Client.modify_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
+        [Client.modify_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
         """
 
     def modify_db_cluster_snapshot_attribute(
@@ -510,7 +514,7 @@ class DocDBClient:
         ValuesToRemove: List[str] = None,
     ) -> ModifyDBClusterSnapshotAttributeResultTypeDef:
         """
-        [Client.modify_db_cluster_snapshot_attribute documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
+        [Client.modify_db_cluster_snapshot_attribute documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
         """
 
     def modify_db_instance(
@@ -525,26 +529,26 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> ModifyDBInstanceResultTypeDef:
         """
-        [Client.modify_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.modify_db_instance)
+        [Client.modify_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.modify_db_instance)
         """
 
     def modify_db_subnet_group(
         self, DBSubnetGroupName: str, SubnetIds: List[str], DBSubnetGroupDescription: str = None
     ) -> ModifyDBSubnetGroupResultTypeDef:
         """
-        [Client.modify_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
+        [Client.modify_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
         """
 
     def reboot_db_instance(
         self, DBInstanceIdentifier: str, ForceFailover: bool = None
     ) -> RebootDBInstanceResultTypeDef:
         """
-        [Client.reboot_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
+        [Client.reboot_db_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
         """
 
     def remove_tags_from_resource(self, ResourceName: str, TagKeys: List[str]) -> None:
         """
-        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
+        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
         """
 
     def reset_db_cluster_parameter_group(
@@ -554,7 +558,7 @@ class DocDBClient:
         Parameters: List["ParameterTypeDef"] = None,
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Client.reset_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
+        [Client.reset_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
         """
 
     def restore_db_cluster_from_snapshot(
@@ -573,7 +577,7 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterFromSnapshotResultTypeDef:
         """
-        [Client.restore_db_cluster_from_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
+        [Client.restore_db_cluster_from_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
         """
 
     def restore_db_cluster_to_point_in_time(
@@ -591,17 +595,17 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterToPointInTimeResultTypeDef:
         """
-        [Client.restore_db_cluster_to_point_in_time documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
+        [Client.restore_db_cluster_to_point_in_time documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
         """
 
     def start_db_cluster(self, DBClusterIdentifier: str) -> StartDBClusterResultTypeDef:
         """
-        [Client.start_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.start_db_cluster)
+        [Client.start_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.start_db_cluster)
         """
 
     def stop_db_cluster(self, DBClusterIdentifier: str) -> StopDBClusterResultTypeDef:
         """
-        [Client.stop_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
+        [Client.stop_db_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
         """
 
     @overload
@@ -609,7 +613,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_clusters"]
     ) -> DescribeDBClustersPaginator:
         """
-        [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
+        [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
         """
 
     @overload
@@ -617,7 +621,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_engine_versions"]
     ) -> DescribeDBEngineVersionsPaginator:
         """
-        [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
+        [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
         """
 
     @overload
@@ -625,7 +629,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_instances"]
     ) -> DescribeDBInstancesPaginator:
         """
-        [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
+        [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
         """
 
     @overload
@@ -633,13 +637,13 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_subnet_groups"]
     ) -> DescribeDBSubnetGroupsPaginator:
         """
-        [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
+        [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_events"]) -> DescribeEventsPaginator:
         """
-        [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
+        [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
         """
 
     @overload
@@ -647,19 +651,25 @@ class DocDBClient:
         self, operation_name: Literal["describe_orderable_db_instance_options"]
     ) -> DescribeOrderableDBInstanceOptionsPaginator:
         """
-        [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
+        [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
         """
 
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
+
     @overload
     def get_waiter(
         self, waiter_name: Literal["db_instance_available"]
     ) -> DBInstanceAvailableWaiter:
         """
-        [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
+        [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["db_instance_deleted"]) -> DBInstanceDeletedWaiter:
         """
-        [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
+        [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
         """
+
+    def get_waiter(self, waiter_name: str) -> Boto3Waiter:
+        pass
