@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for docdb service client paginators.
 
@@ -26,11 +27,12 @@ Usage::
     describe_orderable_db_instance_options_paginator: DescribeOrderableDBInstanceOptionsPaginator = client.get_paginator("describe_orderable_db_instance_options")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Iterator, List, TYPE_CHECKING
+from datetime import datetime
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_docdb.type_defs import (
     DBClusterMessageTypeDef,
     DBEngineVersionMessageTypeDef,
@@ -60,7 +62,7 @@ __all__ = (
 
 class DescribeDBClustersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
+    [Paginator.DescribeDBClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
     """
 
     def paginate(
@@ -70,13 +72,13 @@ class DescribeDBClustersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBClusterMessageTypeDef]:
         """
-        [DescribeDBClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters.paginate)
+        [DescribeDBClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters.paginate)
         """
 
 
 class DescribeDBEngineVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
+    [Paginator.DescribeDBEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
     """
 
     def paginate(
@@ -91,13 +93,13 @@ class DescribeDBEngineVersionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBEngineVersionMessageTypeDef]:
         """
-        [DescribeDBEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions.paginate)
+        [DescribeDBEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions.paginate)
         """
 
 
 class DescribeDBInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
+    [Paginator.DescribeDBInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
     """
 
     def paginate(
@@ -107,13 +109,13 @@ class DescribeDBInstancesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBInstanceMessageTypeDef]:
         """
-        [DescribeDBInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances.paginate)
+        [DescribeDBInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances.paginate)
         """
 
 
 class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
+    [Paginator.DescribeDBSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
     """
 
     def paginate(
@@ -123,13 +125,13 @@ class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DBSubnetGroupMessageTypeDef]:
         """
-        [DescribeDBSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups.paginate)
+        [DescribeDBSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups.paginate)
         """
 
 
 class DescribeEventsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
+    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
     """
 
     def paginate(
@@ -151,13 +153,13 @@ class DescribeEventsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[EventsMessageTypeDef]:
         """
-        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeEvents.paginate)
+        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeEvents.paginate)
         """
 
 
 class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
+    [Paginator.DescribeOrderableDBInstanceOptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
     """
 
     def paginate(
@@ -171,5 +173,5 @@ class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[OrderableDBInstanceOptionsMessageTypeDef]:
         """
-        [DescribeOrderableDBInstanceOptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions.paginate)
+        [DescribeOrderableDBInstanceOptions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions.paginate)
         """
