@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for docdb service client waiters.
 
@@ -18,18 +19,18 @@ Usage::
     db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import List, TYPE_CHECKING
-from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_docdb.type_defs import FilterTypeDef, WaiterConfigTypeDef
+from typing import List
 
+from botocore.waiter import Waiter as Boto3Waiter
+
+from mypy_boto3_docdb.type_defs import FilterTypeDef, WaiterConfigTypeDef
 
 __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 
 
 class DBInstanceAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
+    [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
     """
 
     def wait(
@@ -41,13 +42,13 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
+        [DBInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable.wait)
         """
 
 
 class DBInstanceDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
+    [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
     """
 
     def wait(
@@ -59,5 +60,5 @@ class DBInstanceDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
+        [DBInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted.wait)
         """
